package ru.redrise.example.demo;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

import java.util.Set;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Test;
import org.springframework.boot.test.context.SpringBootTest;

import jakarta.validation.ConstraintViolation;
import jakarta.validation.Validation;
import jakarta.validation.Validator;
import ru.redrise.example.demo.forms.InnForm;

@SpringBootTest
class DemoApplicationTests {

	private Validator validator;

	@BeforeEach
	void makeValidator(){
		this.validator = Validation.buildDefaultValidatorFactory().getValidator();
	}

	@Test
	@DisplayName("Валидация inn: корректный inn; Начальная позиция")
	void innValidate1() {
			InnForm testRequest = new InnForm(null, 1000000000);
			Set<ConstraintViolation<InnForm>> violations = validator.validate(testRequest);

			assertTrue(violations.isEmpty());
	}
	@Test
	@DisplayName("Валидация inn: корректный inn; Конечная позиция")
	void innValidate2() {
			InnForm testRequest = new InnForm(null, 9999999999L);
			Set<ConstraintViolation<InnForm>> violations = validator.validate(testRequest);

			assertTrue(violations.isEmpty());
	}
	@Test
	@DisplayName("Валидация inn: некорректный, несоотвествие по нижнему граничному значению")
	void innValidate3() {
			InnForm testRequest = new InnForm(null, 999999999);
			Set<ConstraintViolation<InnForm>> violations = validator.validate(testRequest);
			
			assertFalse(violations.isEmpty());
			assertEquals(violations.size(), 1);
			assertEquals(violations.iterator().next().getMessage(), "Invalid inn (min value)");
	}
	@Test
	@DisplayName("Валидация inn: некорректный, несоотвествие по верхнему граничному значению")
	void innValidate4() {
			InnForm testRequest = new InnForm(null, 10000000000L);
			Set<ConstraintViolation<InnForm>> violations = validator.validate(testRequest);
			
			assertFalse(violations.isEmpty());
			assertEquals(violations.size(), 1);
			assertEquals(violations.iterator().next().getMessage(), "Invalid inn (max value)");
	}
}
